require("core.options")
require("core.keymaps")
require("core.autostart")

local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not (vim.uv or vim.loop).fs_stat(lazypath) then
	local lazyrepo = "https://github.com/folke/lazy.nvim.git"
	local out = vim.fn.system({ "git", "clone", "--filter=blob:none", "--branch=stable", lazyrepo, lazypath })
	if vim.v.shell_error ~= 0 then
		error("Error cloning lazy.nvim:\n" .. out)
	end
end ---@diagnostic disable-next-line: undefined-field
vim.opt.rtp:prepend(lazypath)

require("lazy").setup({

	-- Neotree
	require("plugins.neotree"),

	-- Colorscheme
	require("plugins.colorscheme"),

	-- Bufferline
	require("plugins.bufferline"),

	-- Lualine
	require("plugins.lualine"),

	-- Treesitter
	require("plugins.treesitter"),

	-- Telescope
	require("plugins.telescope"),

	-- LSP
	require("plugins.lsp"),

	-- Autocomplete
	require("plugins.autocompletion"),

	-- Formatting
	require("plugins.none-ls"),

	-- Gitsigns
	require("plugins.gitsigns"),

	-- Indent blankline
	require("plugins.indent-blankline"),

	-- Misc
	require("plugins.misc"),

	-- Toggleterm
	require("plugins.toggleterm"),

	-- Rest
	require("plugins.rest"),

	-- md-preview
	require("plugins.md-preview"),

	-- Session Manager
	require("plugins.session-manager"),

	-- Alpha
	require("plugins.alpha"),

	-- Leap
	require("plugins.leap"),

	-- Ale
	require("plugins.ale"),
})

-- Setup color scheme
require("catppuccin").setup()
vim.cmd.colorscheme("catppuccin-mocha")

require("toggleterm").setup({
	open_mapping = [[<C-l>]],
	direction = "float",
	border = "shadow",
})

require("peek").setup({ app = { "chromium", "--new-window" } })
